[Nym3-commit] r225 - trunk/nym3/Client

jr at conuropsis.org jr at conuropsis.org
Tue May 3 12:19:10 CEST 2005


Author: jr
Date: 2005-05-03 12:19:10 +0200 (Tue, 03 May 2005)
New Revision: 225

Modified:
   trunk/nym3/Client/Account.py
   trunk/nym3/Client/Main.py
Log:
typo


Modified: trunk/nym3/Client/Account.py
===================================================================
--- trunk/nym3/Client/Account.py	2005-05-03 10:10:20 UTC (rev 224)
+++ trunk/nym3/Client/Account.py	2005-05-03 10:19:10 UTC (rev 225)
@@ -157,12 +157,12 @@
 	# Some data related to the account are loaded only on demand,
 	# this includes the journal, the mailbox, the synbox.
 	self.lock = None
-	self.succeded = True
+	self.succeeded = True
 	self.config = config
 	tagmap = TagMap(config.path + os.sep + 'tagmap')
 	if create:
 	    self.data = {}
-	    self.succeded = False
+	    self.succeeded = False
 	    self['idTag'] = tagmap.getnewId(nickname)
 	    # If the nick already existed, we're out of this because of
 	    # a thrown AlreadySuchAccount.
@@ -190,7 +190,7 @@
 	    self.journal = None
 	    self.mbox = None
 	    self.synbox = None
-	self.succeded = True
+	self.succeeded = True
 	self._lock()
 
     def generateSurbs(self, n):
@@ -343,7 +343,7 @@
 
     def __del__(self):
 	"""Flushes the user account to the disk"""
-	if not self.succeded: return
+	if not self.succeeded: return
         self._save_synbox()
         self._save_mbox()
 	self._save_journal()

Modified: trunk/nym3/Client/Main.py
===================================================================
--- trunk/nym3/Client/Main.py	2005-05-03 10:10:20 UTC (rev 224)
+++ trunk/nym3/Client/Main.py	2005-05-03 10:19:10 UTC (rev 225)
@@ -92,12 +92,11 @@
 	ui.display("wrong passphrase")
     return secring
 
-def decypher_string(string, keyring, key_handles):
-    """decypher string with a key contained in keyring with a handle
+def decipher_string(string, keyring, key_handles):
+    """decipher string with a key contained in keyring with a handle
     among those provided in key_handles. returns the clear text if
     it can be found, None otherwise"""
     #TODO is it correct that any wrong key raises an exception in pk_decrypt?
-    #TODO maybe exiting is too violent, shall we raise an exception?
     clear = None
     for k in key_handles:
 	enckey = _cr.pk_decode_private_key(keyring.get_key(k))
@@ -156,7 +155,7 @@
 	    except Keyring.NewKeyring:
 	    # The Keyring is new. That shouldn't happen
 		raise Exception('Bug keyring?')
-	    clear = decypher_string(com.synSet, secring, account['encKeys'])
+	    clear = decipher_string(com.synSet, secring, account['encKeys'])
 	    if not clear:
 		ui.display("Could not decrypt synopsis")
 		sys.exit(1)



More information about the Nym3-commit mailing list